<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Arrangér</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Flyt Helt Frem</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Flyt Frem</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Flyt Tilbage</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Flyt Helt Tilbage</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Vælg Dette</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiér</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigér</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Overordnede Indstillinger</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Billedindstillinger</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Farve</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Tekstfarve</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Tæller</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Sløringsfaktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Elementskygge</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Elementindstillinger</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Gennemsigtighed</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Luk Andre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Luk Alle</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Luk Alle Til Venstre</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Luk Alle Til Højre</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Værktøjsvalg</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktiveret</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktiveret</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Beskær</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skalére</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotér</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Ændr lærred</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Lodret</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Vandret</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Anvend</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Fortryd</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Kant Og Fylds Synlighed</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Kant Og Fyld</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Kant Uden Fyld</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Hverken Kant Eller Fyld</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Skriftstørrelse</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Understreget</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Billedeffekter</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Ingen Effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Faldskygge</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Gråtoneskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kant</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Modsat Farve</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Begrænset</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Når aktiveret bliver baggrundsbilledet
 til en del af kanvassen.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anvend</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farve:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Lærredets Baggrundsfarve</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Rotér Billedet</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° med uret</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° mod uret</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Vilkårlig</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Positive værdier roterer i urets retning, negative værdier mod urets retning.
Hvis værdien ikke er delelig med 90°, kan det forårsage tab af kvalitet.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Vandret</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Lodret</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Rotér</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Vend</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skalér Billedet</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Bevar Størrelsesforhold</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Højde:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Klistermærke</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Vælg</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Markeringsfirkant</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Markeringsellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Markeringspen</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dobbeltpil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Slør</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Firkant</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummermarkør</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Klistermærke</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelér</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Tekstmarkør</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Tekstpil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Nummerpil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliker</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Zoom ind (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Zoom ud (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Nulstil Zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Nulstil Zoom</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Tilpas til billede</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Tilpas billede til visning</translation>
    </message>
</context>
</TS>
